/**************************************************************************
 *                                                                        *
 *              This code is copyright (c) 1998                           *
 *                       Sundial Systems Corp.                            *
 *                                                                        *
 *                        ALL RIGHTS RESERVED                             *
 *                                                                        *
 **************************************************************************/

#ifndef _MH_filefilter

#define _MH_filefilter



/* Memory management for some of the functions is handled through       */
/* Mesa's internal memory managment routines.  There are two sets that  */
/* can be used depending on the compiler used.  The first set is        */
/* OptiLinked for use with IBM's C/C++ compilers.  The other set is     */
/* for use with other compilers and languages.  They are _System linked */
/* for portability.  The functions can be used interchangably as the    */
/* system linked ones just call the OptiLink ones internally.           */
#ifndef __MH_MEMORY__
#ifdef __cplusplus
extern "C"
{
#endif

extern void MFree(void *);
extern void *MMalloc(int size);
extern void *MRealloc(void *,int size);

extern void _System SysMFree(void *);
extern void *_System SysMRealloc(void *,int size);
extern void *_System SysMMalloc(int size);
#ifdef __cplusplus
}
#endif
#endif


class _Export MesaFileFilter {
public:
    MesaFileFilter() {};
    virtual ~MesaFileFilter() {};

    /* Convert the file. */
    /*    data is the data to be converted        */
    /*    len is the len of data                  */
    /*    outlen is where you need to record the  */
    /*               length of the returned data  */
    /*    model is an internal token representing */
    /*       the workbook being imported/exported */
    /*    filename is the name of the file.       */
    /* You probably shouldn't need to use model   */
    /* and filename.  You may need filename if    */
    /* some data is stored in a separate file.    */
    /* Example: WK3 files store extra stuff in    */
    /* FM3 file.  You would need the filename to  */
    /* determine where the FM3 file is.           */
    /*                                            */
    /* return the data in a form readable by Mesa */
    /* or return NULL if you could not import     */
    /* the data.  The returned data must have     */
    /* been created with MMalloc and it will be   */
    /* MFree'd when Mesa is done with it.         */
    virtual void *importFile(void *data ,int len,
                             int &outlen,void *model,const char *filename) = 0;
    virtual void *exportFile(void *data ,int len,
                             int &outlen,void *model,const char *filename) = 0;

    /* Get the name of the file type */
    virtual const char *getName() = 0;
    /* Get the extension of the file type */
    virtual const char *getExtension() = 0;

    /* Return 1 if the file filter supports the desired action */
    virtual int canImport() = 0;
    virtual int canExport() = 0;


    /* For an export filter, this specifies what     */
    /* format you want the data to be in originally. */
    /* It can be:                                    */
    /*     0  -  Mesa native format (Mesa JDK)       */
    /*     1  -  WK1                                 */
    /*     2  -  WK3                                 */
    /*     3  -  WK4                                 */
    /*     4  -  XLS  version 3                      */
    /*     5  -  XLS  version 4                      */
    /*     6  -  Mesa 2.1.x format (Mesa DPP)        */
    /*     8  -  XLS  version 97                     */
    /*     9  -  Integer                             */ 
    virtual int getExportDataType() = 0;


    /* Gets the file filter version.  Always return */
    /* 1 at this time.  Future version of Mesa may  */
    /* create a subclass for extended               */
    /* capababilities.  Those subclasses would      */
    /* return higher numbers.  (this is kind of a   */
    /* runtime type check)                          */
    virtual int getFileFilterVersion() {
        return 1;
    }
};




#endif


